searchData={"items":[{"type":"module","title":"Ecto.DateTimeRange","doc":"`Ecto.DateTimeRange` provides modules implementing `Ecto.Type` to allow\nusage of Postgres range times encoding timestamp ranges.","ref":"Ecto.DateTimeRange.html"},{"type":"function","title":"Ecto.DateTimeRange.sigil_t/2","doc":"Create an `Ecto.UTCDateTimeRange` from two ISO8601 strings.","ref":"Ecto.DateTimeRange.html#sigil_t/2"},{"type":"function","title":"Example - Ecto.DateTimeRange.sigil_t/2","doc":"```\niex> import Ecto.DateTimeRange, only: [sigil_t: 2]\n...>\niex> ~t(2020-02-02T00:01:00Z..2020-02-02T00:01:01Z)\n%Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}\n...>\niex> ~t(2020-02-02T00:01:00Z..2020-02-02T00:01:01Z)U\n%Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}\n...>\niex> ~t(2020-02-02T00:01:00..2020-02-02T00:01:01)N\n%Ecto.DateTimeRange.NaiveDateTime{start_at: ~N[2020-02-02T00:01:00], end_at: ~N[2020-02-02T00:01:01]}\n...>\niex> ~t(00:01:00..00:01:01)T\n%Ecto.DateTimeRange.Time{start_at: ~T[00:01:00], end_at: ~T[00:01:01]}\n...>\niex> ~t(hi there)\n** (ArgumentError) Unable to parse DateTime(s) from input\n```","ref":"Ecto.DateTimeRange.html#sigil_t/2-example"},{"type":"module","title":"Ecto.DateTimeRange.NaiveDateTime","doc":"An `Ecto.Type` wrapping a `:tsrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `:naive_datetime` values.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.NaiveDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","ref":"Ecto.DateTimeRange.NaiveDateTime.html"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.cast/1","doc":"Converts user-provided data (for example from a form) to the Elixir term.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#cast/1"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.contains?/2","doc":"Returns true or false depending on whether the time is falls within the\nspecified range.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#contains?/2"},{"type":"function","title":"Example - Ecto.DateTimeRange.NaiveDateTime.contains?/2","doc":"```\niex> import Ecto.DateTimeRange\niex> range = ~t[2020-01-01T01:00:00..2020-01-02T01:00:00]N\n...>\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-01T00:59:59Z])\nfalse\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-01T01:00:00Z])\ntrue\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-02T00:59:59Z])\ntrue\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-02T01:00:00Z])\nfalse\niex> Ecto.DateTimeRange.NaiveDateTime.contains?(range, ~N[2020-01-03T01:00:00Z])\nfalse\n```","ref":"Ecto.DateTimeRange.NaiveDateTime.html#contains?/2-example"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.dump/1","doc":"Converts the Elixir term to the Ecto native type.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#dump/1"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.embed_as/1","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#embed_as/1"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.equal?/2","doc":"Checks if two terms are equal.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#equal?/2"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.load/1","doc":"Converts the Ecto native type to the Elixir term.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#load/1"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.parse/1","doc":"Create an `Ecto.DateTimeRange.NaiveDateTime` from two ISO8601 strings.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#parse/1"},{"type":"function","title":"Example - Ecto.DateTimeRange.NaiveDateTime.parse/1","doc":"```\niex> Ecto.DateTimeRange.NaiveDateTime.parse(\"2020-02-02T00:01:00..2020-02-02T00:01:01\")\n{:ok, %Ecto.DateTimeRange.NaiveDateTime{start_at: ~N[2020-02-02T00:01:00], end_at: ~N[2020-02-02T00:01:01]}}\n\niex> Ecto.DateTimeRange.NaiveDateTime.parse(\"2020-02-02T00:01:00..later\")\n{:error, \"Unable to parse NaiveDateTime(s) from input\"}\n```","ref":"Ecto.DateTimeRange.NaiveDateTime.html#parse/1-example"},{"type":"type","title":"Ecto.DateTimeRange.NaiveDateTime.t/0","doc":"","ref":"Ecto.DateTimeRange.NaiveDateTime.html#t:t/0"},{"type":"function","title":"Ecto.DateTimeRange.NaiveDateTime.type/0","doc":"Declares the native type that will be used in the database.","ref":"Ecto.DateTimeRange.NaiveDateTime.html#type/0"},{"type":"module","title":"Ecto.DateTimeRange.Time","doc":"An `Ecto.Type` wrapping a `:tsrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `t:Time.t()` values.\n\nThis type does not do any time zone conversions--times going in will be times coming out.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.Time\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","ref":"Ecto.DateTimeRange.Time.html"},{"type":"function","title":"Ecto.DateTimeRange.Time.cast/1","doc":"Converts user-provided data (for example from a form) to the Elixir term.","ref":"Ecto.DateTimeRange.Time.html#cast/1"},{"type":"function","title":"Ecto.DateTimeRange.Time.contains?/2","doc":"Returns true or false depending on whether the time is falls within the\nspecified range. **Note:** this assumes that the range is in the same time zone as\nwhatever time or date time it is compared against.","ref":"Ecto.DateTimeRange.Time.html#contains?/2"},{"type":"function","title":"Example - Ecto.DateTimeRange.Time.contains?/2","doc":"```\niex> import Ecto.DateTimeRange\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[00:00:00])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[01:00:00])\ntrue\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[01:59:59])\ntrue\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~T[02:00:00])\nfalse\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~N[2022-01-01T00:00:00])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~N[2022-01-01T01:00:00])\ntrue\n...>\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~U[2022-01-01T00:00:00Z])\nfalse\niex> Ecto.DateTimeRange.Time.contains?(~t[01:00:00..02:00:00]T, ~U[2022-01-01T01:00:00Z])\ntrue\n```","ref":"Ecto.DateTimeRange.Time.html#contains?/2-example"},{"type":"function","title":"Ecto.DateTimeRange.Time.dump/1","doc":"Converts the Elixir term to the Ecto native type.","ref":"Ecto.DateTimeRange.Time.html#dump/1"},{"type":"function","title":"Ecto.DateTimeRange.Time.embed_as/1","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","ref":"Ecto.DateTimeRange.Time.html#embed_as/1"},{"type":"function","title":"Ecto.DateTimeRange.Time.equal?/2","doc":"Checks if two terms are equal.","ref":"Ecto.DateTimeRange.Time.html#equal?/2"},{"type":"function","title":"Ecto.DateTimeRange.Time.load/1","doc":"Converts the Ecto native type to the Elixir term.","ref":"Ecto.DateTimeRange.Time.html#load/1"},{"type":"function","title":"Ecto.DateTimeRange.Time.parse/1","doc":"Create an `Ecto.DateTimeRange.Time` from two ISO8601 strings.","ref":"Ecto.DateTimeRange.Time.html#parse/1"},{"type":"function","title":"Example - Ecto.DateTimeRange.Time.parse/1","doc":"```\niex> Ecto.DateTimeRange.Time.parse(\"00:01:00..00:01:01\")\n{:ok, %Ecto.DateTimeRange.Time{start_at: ~T[00:01:00], end_at: ~T[00:01:01]}}\n\niex> Ecto.DateTimeRange.Time.parse(\"00:01:00..later\")\n{:error, \"Unable to parse Time(s) from input\"}\n```","ref":"Ecto.DateTimeRange.Time.html#parse/1-example"},{"type":"type","title":"Ecto.DateTimeRange.Time.t/0","doc":"","ref":"Ecto.DateTimeRange.Time.html#t:t/0"},{"type":"function","title":"Ecto.DateTimeRange.Time.type/0","doc":"Declares the native type that will be used in the database.","ref":"Ecto.DateTimeRange.Time.html#type/0"},{"type":"module","title":"Ecto.DateTimeRange.UTCDateTime","doc":"An `Ecto.Type` wrapping a `:tstzrange` Postgres column. To the application, it appears as\na struct with `:start_at` and `:end_at`, with `:utc_datetime` values.\n\n```\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.UTCDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","ref":"Ecto.DateTimeRange.UTCDateTime.html"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.cast/1","doc":"Converts user-provided data (for example from a form) to the Elixir term.","ref":"Ecto.DateTimeRange.UTCDateTime.html#cast/1"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.contains?/2","doc":"Returns true or false depending on whether the time is falls within the\nspecified range.","ref":"Ecto.DateTimeRange.UTCDateTime.html#contains?/2"},{"type":"function","title":"Example - Ecto.DateTimeRange.UTCDateTime.contains?/2","doc":"```\niex> import Ecto.DateTimeRange\niex> range = ~t[2020-01-01T01:00:00Z..2020-01-02T01:00:00Z]U\n...>\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-01T00:59:59Z])\nfalse\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-01T01:00:00Z])\ntrue\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-02T00:59:59Z])\ntrue\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-02T01:00:00Z])\nfalse\niex> Ecto.DateTimeRange.UTCDateTime.contains?(range, ~U[2020-01-03T01:00:00Z])\nfalse\n```","ref":"Ecto.DateTimeRange.UTCDateTime.html#contains?/2-example"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.dump/1","doc":"Converts the Elixir term to the Ecto native type.","ref":"Ecto.DateTimeRange.UTCDateTime.html#dump/1"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.embed_as/1","doc":"Declares than when used in embedded schemas, the type will be dumped before being encoded.","ref":"Ecto.DateTimeRange.UTCDateTime.html#embed_as/1"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.equal?/2","doc":"Checks if two terms are equal.","ref":"Ecto.DateTimeRange.UTCDateTime.html#equal?/2"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.load/1","doc":"Converts the Ecto native type to the Elixir term.","ref":"Ecto.DateTimeRange.UTCDateTime.html#load/1"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.parse/1","doc":"Create an `Ecto.DateTimeRange.UTCDateTime` from two ISO8601 strings.","ref":"Ecto.DateTimeRange.UTCDateTime.html#parse/1"},{"type":"function","title":"Example - Ecto.DateTimeRange.UTCDateTime.parse/1","doc":"```\niex> Ecto.DateTimeRange.UTCDateTime.parse(\"2020-02-02T00:01:00Z..2020-02-02T00:01:01Z\")\n{:ok, %Ecto.DateTimeRange.UTCDateTime{start_at: ~U[2020-02-02T00:01:00Z], end_at: ~U[2020-02-02T00:01:01Z]}}\n\niex> Ecto.DateTimeRange.UTCDateTime.parse(\"2020-02-02T00:01:00Z..later\")\n{:error, \"Unable to parse DateTime(s) from input\"}\n```","ref":"Ecto.DateTimeRange.UTCDateTime.html#parse/1-example"},{"type":"type","title":"Ecto.DateTimeRange.UTCDateTime.t/0","doc":"","ref":"Ecto.DateTimeRange.UTCDateTime.html#t:t/0"},{"type":"function","title":"Ecto.DateTimeRange.UTCDateTime.type/0","doc":"Declares the native type that will be used in the database.","ref":"Ecto.DateTimeRange.UTCDateTime.html#type/0"},{"type":"module","title":"Ecto.DateTimeRange.Operators","doc":"Provides operators for querying against ranges in PostgreSQL.","ref":"Ecto.DateTimeRange.Operators.html"},{"type":"module","title":"Usage - Ecto.DateTimeRange.Operators","doc":"```\nimport Ecto.Query\nimport Ecto.DateTimeRange.Operators\n\nnow = DateTime.utc_now()\nfrom(thing in Thing, where: contains(thing.during, ^now))\n```","ref":"Ecto.DateTimeRange.Operators.html#module-usage"},{"type":"macro","title":"Ecto.DateTimeRange.Operators.contains/2","doc":"Filter by rows where the given datetime falls within the range.","ref":"Ecto.DateTimeRange.Operators.html#contains/2"},{"type":"macro","title":"Examples - Ecto.DateTimeRange.Operators.contains/2","doc":"```\nfrom(thing in Thing, where: contains(thing.during_utc, ^DateTime.utc_now()))\n```","ref":"Ecto.DateTimeRange.Operators.html#contains/2-examples"},{"type":"extras","title":"Overview","doc":"# Overview\n\n`Ecto DateTimeRange` is a library extending Ecto with field types to handle PostgreSQL column types\nencapsulating timestamp ranges. The types provided by this library can be paired with view\ncomponents in order to facilitate editing ranges in forms.","ref":"overview.html"},{"type":"extras","title":"Installation - Overview","doc":"Add the [hex package](https://hex.pm/packages/ecto_date_time_range) to `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ecto_date_time_range, \"~> 0.1\"}\n  ]\nend\n```\n\nIf `DateTime`s will be shifted between time zones at any point during the value's lifecycle, for\ninstance to show/edit timestamps in the time zone reported by a person's browser, then a time zone\ndatabase must also be added and configured as Elixir's `:time_zone_database`.\n\n- https://github.com/mathieuprog/tz\n- https://github.com/lau/tzdata","ref":"overview.html#installation"},{"type":"extras","title":"Migrations - Overview","doc":"Add [migrations](migrations.md) using `:tstzrange` column types.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :performed_during, :tstzrange\n    end\n\n    create table(:thing_schedules) do\n      add :performed_every, :tsrange\n    end\n  end\nend\n```\n\nFor more detailed information see the [migrations guide](migrations.md).","ref":"overview.html#migrations"},{"type":"extras","title":"Schemas - Overview","doc":"```elixir\ndefmodule Core.Thing do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"things\" do\n    field :performed_during, Ecto.DateTimeRange.UTCDateTime\n  end\n\n  @required_attrs ~w[performed_during]a\n  def changeset(data \\\\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```\n\n```elixir\ndefmodule Core.ThingSchedule do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"thing_scheduless\" do\n    field :performed_every, Ecto.DateTimeRange.Time\n  end\n\n  @required_attrs ~w[performed_every]a\n  def changeset(data \\\\ %__MODULE__{}, attrs) do\n    data\n    |> cast(attrs, @required_attrs)\n    |> validate_required(@required_attrs)\n  end\nend\n```","ref":"overview.html#schemas"},{"type":"extras","title":"Migrations","doc":"# Migrations\n\n`Ecto.UTCDateTime` ranges can be indicated in migrations with the `:tstzrange` column type.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :profile_id, references(:profiles), null: false\n      add :performed_during, :tstzrange\n    end\n  end\nend\n```\n\n`Ecto.DateTime.Time` ranges can be indicated in migrations with the `:tsrange` column type.\n\n```elixir\ndefmodule Core.Repo.Migrations.AddThings do\n  use Ecto.Migration\n\n  def change do\n    create table(:things) do\n      add :profile_id, references(:profiles), null: false\n      add :performed_every, :tsrange\n    end\n  end\nend\n```","ref":"migrations.html"},{"type":"extras","title":"Indexes - Migrations","doc":"`GIST` or `SP-GIST` indexes and constraints can include range operators:\n\n```elixir\ndefmodule Core.Repo.Migrations.ExcludeOverlappingThings do\n  use Ecto.Migration\n\n  def change do\n    create constraint(\n             :things,\n             :no_overlapping_things,\n             exclude: ~s|gist (profile_id with =, performed_during with &&)|\n           )\n  end\nend\n```","ref":"migrations.html#indexes"},{"type":"extras","title":"Form Data","doc":"# Form Data\n\nTypes provided by this library are intended to be used with nested form data that can be cast to\nranges as a single unit. For example, a heex component could be written as follows:\n\n```elixir\ndefmodule Web.Components do\n  use Phoenix.HTML\n\n  import Phoenix.LiveView.Helpers\n\n  def utc_date_time_range_field(assigns) do\n    ~H\"\"\"\n     \n      <%= error_tag @f, @field %>\n       \n       \n       \n     \n    \"\"\"\n  end\n\n  def time_range_field(assigns) do\n  ~H\"\"\"\n   \n     \n      <%= error_tag @f, @field %>\n       \n       \n     \n   \n  \"\"\"\n  end\n\n  defp form_name(form), do: form.name\n\n  defp utc_date_time_part(form, field, part) do\n    form.source\n    |> Ecto.Changeset.get_field(field)\n    |> case do\n      nil -> DateTime.utc_now()\n      %Ecto.DateTimeRange.UTCDateTime{} = range -> Map.get(range, part) |> to_time_zone(\"America/Los_Angeles\")\n    end\n  end\n\n  defp time_part(form, field, part) do\n    form.source\n    |> Ecto.Changeset.get_field(field)\n    |> case do\n      nil -> default_time(part)\n      %Ecto.DateTimeRange.Time{} = range -> Map.get(range, part)\n    end\n    |> to_time_value()\n  end\n\n  defp default_time(:start_at), do: ~T[06:00:00]\n  defp default_time(:end_at), do: ~T[18:00:00]\n\n  defp to_time_value(%Time{} = time), do: Calendar.strftime(time, \"%H:%M\")\n\n  defp to_time_zone(%DateTime{} = time, tz), do: DateTime.add(time, tz_offset(tz), :second)\n\n  defp tz_offset(tz) do\n    {:ok, %{std_offset: _, utc_offset: offset, zone_abbr: _}} =\n      Calendar.get_time_zone_database().time_zone_periods_from_wall_datetime(DateTime.utc_now(), tz)\n\n    offset\n  end\nend\n```\n\nComponents such as this can be used in a parent live view:\n\n```elixir\ndefmodule Web.MyLiveView do\n  use Web, :live_view\n  import Web.Components\n\n  @impl Phoenix.LiveView\n  def render(assigns) do\n    ~H\"\"\"\n    <.form let={f} for={@changeset} id=\"thing-form\" phx-change=\"validate\">\n      <.utc_date_time_range_field id=\"performed-during\" f={f} field={:performed_during} />\n      <%= submit(\"Save\") %>\n    </.form>\n    \"\"\"\n  end\n\n  @impl Phoenix.LiveView\n  def mount(_params, _session, socket) do\n    socket =\n      socket\n      |> assign(:changeset, Core.Thing.changeset(%{}))\n\n    {:ok, socket}\n  end\n\n  @impl Phoenix.LiveView\n  def handle_event(\"validate\", %{\"thing\" => params}, socket) do\n    socket = socket |> assign(changeset: Core.Things.changeset(params))\n    {:noreply, socket}\n  end\n\nend\n```\n\nWhen this form is sent to the server via `POST` or in a LiveView's `phx-change` or `phx-submit`, the\nparams will arrive in the following format, which matches that expected by\n`Ecto.DateTimeRange.UTCDateTime.cast/1`:\n\n```elixir\n%{\n  \"thing\" => %{\n    \"performed_during\" => %{\n        \"start_at\" => \"2022-06-22 01:00:00\",\n        \"end_at\" => \"2022-06-22 01:00:00\",\n        \"tz\" => \"Etc/UTC\"\n      }\n  }\n}\n```","ref":"forms.html"},{"type":"extras","title":"Change Log","doc":"# Change Log","ref":"changelog.html"},{"type":"extras","title":"Unreleased - Change Log","doc":"","ref":"changelog.html#unreleased"},{"type":"extras","title":"2.0.0 - Change Log","doc":"- Test against Elixir 1.18.\n- **Breaking change:** Drop support for Elixir 1.15.","ref":"changelog.html#2-0-0"},{"type":"extras","title":"1.3.0 - Change Log","doc":"- require Elixir 1.15 or greater\n- test against the latest version of Erlang and Elixir","ref":"changelog.html#1-3-0"},{"type":"extras","title":"1.2.2 - Change Log","doc":"- Updated dependencies.","ref":"changelog.html#1-2-2"},{"type":"extras","title":"1.2.1 - Change Log","doc":"- Relax version matching of `tz` when present.","ref":"changelog.html#1-2-1"},{"type":"extras","title":"1.2.0 - Change Log","doc":"- Documentation TOC organization.\n- Add `Ecto.DateTimeRange.NaiveDateTime`.","ref":"changelog.html#1-2-0"},{"type":"extras","title":"1.1.0 - Change Log","doc":"- `Ecto.DateTimeRange.Time.contains?/2` handles `DateTime` and `NaiveDateTime` values.","ref":"changelog.html#1-1-0"},{"type":"extras","title":"1.0.0 - Change Log","doc":"**Breaking Changes**\n\n- Remove `Ecto.UTCDateTimeRange` and `Ecto.UTCTimeRange`.\n- Changes `sigil_t`:\n  - Defaults to `Ecto.DateTimeRange.UTCDateTime`.\n  - Changes `U` modifier to return `Ecto.DateTimeRange.UTCDateTime`.\n  - Changes `T` modifier to return `Ecto.DateTimeRange.Time`.\n\n**Upgrading**\n\n1. Update to version `0.99.0`.\n1. Fix all deprecation warnings by switching code to use `Ecto.DateTimeRange.UTCDateTime` instead of\n  `Ecto.UTCDateTimeRange` and `Ecto.DateTimeRange.Time` instead of `Ecto.UTCTimeRange`. **Important:**\n  when using time ranges, `tz` is ignored when provided in form params, and no time zone casting is\n  applied. Any time zone logic must be applied in application code.\n1. Switch usage of `sigil_t` to use the `u` or `t` modifiers, specifying the new modules.\n1. Update to version `1.0.0`.\n1. Switch usage of `sigil_t` to use the `U` or `T` modifiers.","ref":"changelog.html#1-0-0"},{"type":"extras","title":"0.99.0 - Change Log","doc":"- Deprecate `Ecto.UTCDateTimeRange` and `Ecto.UTCTimeRange`.\n- Add `Ecto.DateTimeRange.UTCDateTime` type.\n\nThis release represents the last `0.x` version.","ref":"changelog.html#0-99-0"},{"type":"extras","title":"0.4.0 - Change Log","doc":"- Add `Ecto.DateTimeRange.Time` type, representing a naive time range.","ref":"changelog.html#0-4-0"},{"type":"extras","title":"0.3.1 - Change Log","doc":"- Fix `Ecto.UTCTimeRange.contains?/2` to handle ranges crossing day barrier.","ref":"changelog.html#0-3-1"},{"type":"extras","title":"0.3.0 - Change Log","doc":"- Add `Ecto.UTCDateTimeRange.contains?/2`.\n- Add `Ecto.UTCTimeRange.contains?/2`.","ref":"changelog.html#0-3-0"},{"type":"extras","title":"0.2.0 - Change Log","doc":"- Move `~t` to `Ecto.DateTimeRange`.\n- Add `Ecto.UTCTimeRange` type.\n- Add `Ecto.RangeOperators.contains/2` macro.","ref":"changelog.html#0-2-0"},{"type":"extras","title":"0.1.1 - Change Log","doc":"- Update docs regarding setup, form data.\n- Clarify errors in UTCDateTimeRange's `sigil_t` and `parse`.","ref":"changelog.html#0-1-1"},{"type":"extras","title":"0.1.0 - Change Log","doc":"- Initial release of `Ecto.UTCDateTimeRange`.","ref":"changelog.html#0-1-0"},{"type":"extras","title":"LICENSE","doc":"Copyright 2022-2025 syncrhonal.dev\n\n\n                            Apache License\n                        Version 2.0, January 2004\n                      http://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1. Definitions.\n\n    \"License\" shall mean the terms and conditions for use, reproduction,\n    and distribution as defined by Sections 1 through 9 of this document.\n\n    \"Licensor\" shall mean the copyright owner or entity authorized by\n    the copyright owner that is granting the License.\n\n    \"Legal Entity\" shall mean the union of the acting entity and all\n    other entities that control, are controlled by, or are under common\n    control with that entity. For the purposes of this definition,\n    \"control\" means (i) the power, direct or indirect, to cause the\n    direction or management of such entity, whether by contract or\n    otherwise, or (ii) ownership of fifty percent (50%) or more of the\n    outstanding shares, or (iii) beneficial ownership of such entity.\n\n    \"You\" (or \"Your\") shall mean an individual or Legal Entity\n    exercising permissions granted by this License.\n\n    \"Source\" form shall mean the preferred form for making modifications,\n    including but not limited to software source code, documentation\n    source, and configuration files.\n\n    \"Object\" form shall mean any form resulting from mechanical\n    transformation or translation of a Source form, including but\n    not limited to compiled object code, generated documentation,\n    and conversions to other media types.\n\n    \"Work\" shall mean the work of authorship, whether in Source or\n    Object form, made available under the License, as indicated by a\n    copyright notice that is included in or attached to the work\n    (an example is provided in the Appendix below).\n\n    \"Derivative Works\" shall mean any work, whether in Source or Object\n    form, that is based on (or derived from) the Work and for which the\n    editorial revisions, annotations, elaborations, or other modifications\n    represent, as a whole, an original work of authorship. For the purposes\n    of this License, Derivative Works shall not include works that remain\n    separable from, or merely link (or bind by name) to the interfaces of,\n    the Work and Derivative Works thereof.\n\n    \"Contribution\" shall mean any work of authorship, including\n    the original version of the Work and any modifications or additions\n    to that Work or Derivative Works thereof, that is intentionally\n    submitted to Licensor for inclusion in the Work by the copyright owner\n    or by an individual or Legal Entity authorized to submit on behalf of\n    the copyright owner. For the purposes of this definition, \"submitted\"\n    means any form of electronic, verbal, or written communication sent\n    to the Licensor or its representatives, including but not limited to\n    communication on electronic mailing lists, source code control systems,\n    and issue tracking systems that are managed by, or on behalf of, the\n    Licensor for the purpose of discussing and improving the Work, but\n    excluding communication that is conspicuously marked or otherwise\n    designated in writing by the copyright owner as \"Not a Contribution.\"\n\n    \"Contributor\" shall mean Licensor and any individual or Legal Entity\n    on behalf of whom a Contribution has been received by Licensor and\n    subsequently incorporated within the Work.\n\n2. Grant of Copyright License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    copyright license to reproduce, prepare Derivative Works of,\n    publicly display, publicly perform, sublicense, and distribute the\n    Work and such Derivative Works in Source or Object form.\n\n3. Grant of Patent License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    (except as stated in this section) patent license to make, have made,\n    use, offer to sell, sell, import, and otherwise transfer the Work,\n    where such license applies only to those patent claims licensable\n    by such Contributor that are necessarily infringed by their\n    Contribution(s) alone or by combination of their Contribution(s)\n    with the Work to which such Contribution(s) was submitted. If You\n    institute patent litigation against any entity (including a\n    cross-claim or counterclaim in a lawsuit) alleging that the Work\n    or a Contribution incorporated within the Work constitutes direct\n    or contributory patent infringement, then any patent licenses\n    granted to You under this License for that Work shall terminate\n    as of the date such litigation is filed.\n\n4. Redistribution. You may reproduce and distribute copies of the\n    Work or Derivative Works thereof in any medium, with or without\n    modifications, and in Source or Object form, provided that You\n    meet the following conditions:\n\n    (a) You must give any other recipients of the Work or\n        Derivative Works a copy of this License; and\n\n    (b) You must cause any modified files to carry prominent notices\n        stating that You changed the files; and\n\n    (c) You must retain, in the Source form of any Derivative Works\n        that You distribute, all copyright, patent, trademark, and\n        attribution notices from the Source form of the Work,\n        excluding those notices that do not pertain to any part of\n        the Derivative Works; and\n\n    (d) If the Work includes a \"NOTICE\" text file as part of its\n        distribution, then any Derivative Works that You distribute must\n        include a readable copy of the attribution notices contained\n        within such NOTICE file, excluding those notices that do not\n        pertain to any part of the Derivative Works, in at least one\n        of the following places: within a NOTICE text file distributed\n        as part of the Derivative Works; within the Source form or\n        documentation, if provided along with the Derivative Works; or,\n        within a display generated by the Derivative Works, if and\n        wherever such third-party notices normally appear. The contents\n        of the NOTICE file are for informational purposes only and\n        do not modify the License. You may add Your own attribution\n        notices within Derivative Works that You distribute, alongside\n        or as an addendum to the NOTICE text from the Work, provided\n        that such additional attribution notices cannot be construed\n        as modifying the License.\n\n    You may add Your own copyright statement to Your modifications and\n    may provide additional or different license terms and conditions\n    for use, reproduction, or distribution of Your modifications, or\n    for any such Derivative Works as a whole, provided Your use,\n    reproduction, and distribution of the Work otherwise complies with\n    the conditions stated in this License.\n\n5. Submission of Contributions. Unless You explicitly state otherwise,\n    any Contribution intentionally submitted for inclusion in the Work\n    by You to the Licensor shall be under the terms and conditions of\n    this License, without any additional terms or conditions.\n    Notwithstanding the above, nothing herein shall supersede or modify\n    the terms of any separate license agreement you may have executed\n    with Licensor regarding such Contributions.\n\n6. Trademarks. This License does not grant permission to use the trade\n    names, trademarks, service marks, or product names of the Licensor,\n    except as required for reasonable and customary use in describing the\n    origin of the Work and reproducing the content of the NOTICE file.\n\n7. Disclaimer of Warranty. Unless required by applicable law or\n    agreed to in writing, Licensor provides the Work (and each\n    Contributor provides its Contributions) on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n    implied, including, without limitation, any warranties or conditions\n    of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n    PARTICULAR PURPOSE. You are solely responsible for determining the\n    appropriateness of using or redistributing the Work and assume any\n    risks associated with Your exercise of permissions under this License.\n\n8. Limitation of Liability. In no event and under no legal theory,\n    whether in tort (including negligence), contract, or otherwise,\n    unless required by applicable law (such as deliberate and grossly\n    negligent acts) or agreed to in writing, shall any Contributor be\n    liable to You for damages, including any direct, indirect, special,\n    incidental, or consequential damages of any character arising as a\n    result of this License or out of the use or inability to use the\n    Work (including but not limited to damages for loss of goodwill,\n    work stoppage, computer failure or malfunction, or any and all\n    other commercial damages or losses), even if such Contributor\n    has been advised of the possibility of such damages.\n\n9. Accepting Warranty or Additional Liability. While redistributing\n    the Work or Derivative Works thereof, You may choose to offer,\n    and charge a fee for, acceptance of support, warranty, indemnity,\n    or other liability obligations and/or rights consistent with this\n    License. However, in accepting such obligations, You may act only\n    on Your own behalf and on Your sole responsibility, not on behalf\n    of any other Contributor, and only if You agree to indemnify,\n    defend, and hold each Contributor harmless for any liability\n    incurred by, or claims asserted against, such Contributor by reason\n    of your accepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS\n\nAPPENDIX: How to apply the Apache License to your work.\n\n    To apply the Apache License to your work, attach the following\n    boilerplate notice, with the fields enclosed by brackets \"[]\"\n    replaced with your own identifying information. (Don't include\n    the brackets!)  The text should be enclosed in the appropriate\n    comment syntax for the file format. We also recommend that a\n    file or class name and description of purpose be included on the\n    same \"printed page\" as the copyright notice for easier\n    identification within third-party archives.\n\nCopyright [yyyy] [name of copyright owner]\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}